# plcg

A package created by the Pardee Lab Computation Group containing a variety of python utilities which we have found useful in a variety of biology projects.

## Software requirements:

[Local Colabfold](https://github.com/YoshitakaMo/localcolabfold)

Must be in path such that the user can call colabfold_batch from inside terminal in which you are running the project

[pyrosetta](https://www.pyrosetta.org/)

Should be installed into it's own environment as it is not yet supported in python 3.11, and thus we take the conda path as a function argument
